##############################################
## Figure 1: Corporate ATS Cases from 1960-2010
##############################################

rm(list = ls())

# Loading Plot Options:
source("Code/Helper_Scripts/Plot_Options.R")

# Loading Case Data:
ats_list <- read.csv("Data/ACTA_CorpCaseList.csv")
names(ats_list) <- tolower(names(ats_list))
ats_list <- data.table(ats_list)

# Counts by year:
plot_df <- ats_list[, list(freq = .N), by = year] %>% as.data.frame()

# Filling in the time-series:
full_ts <- as.data.frame(cbind(c(1960:2010), rep(0, length(c(1960:2010)))))
names(full_ts) <- c("year", "freq")
plot_df <- arrange(rbind(plot_df, full_ts[full_ts$year %nin% plot_df$year, ]), year)

f <- ggplot(data = plot_df, aes(x = year, y = freq)) +
	geom_line(alpha = .3, color = "navy", lwd = 1) +
	geom_vline(xintercept = 1980, color = "darkred", lty = 2, lwd = 1) +
	geom_vline(xintercept = 1995, color = "darkred", lty = 2, lwd = 1) +
	geom_text(data = NULL, x = 1976, y = 14, label = "Fillartiga", color = "darkred") +
	geom_text(data = NULL, x = 1992, y = 15, label = "Kadic", color = "darkred") +
	xlab("") + ylab("Number of Cases") +
	geom_point(color = "navy") +
	scale_y_continuous(limits = c(0, 16)) +
	theme_bw() + dc_opts

print(f)
