##############################################
## Figure 2: Selected Firms’ Stock Prices during April 17, 2013 Event Window
##############################################

rm(list = ls())

# Loading Plot Options:
source("Code/Helper_Scripts/Plot_Options.R")

# Loading Adj Close data:
source("Code/Helper_Scripts/AdjClose_DataClean.R")

##############################################
# Defining static arguments:
begin_series <- ymd('2013-04-11')
end_series <- ymd('2013-05-04')

event_begin <- as.numeric(ymd('2013-04-18'))
event_end <- as.numeric(ymd('2013-04-27'))

##############################################
# Writing Function to create plots:
TS_Plot <- function(stock, title) {
	df <- subset(price_df,
	subset = c(ticker_sym == stock &
		date >= begin_series & date <= end_series))

	f <- ggplot(df, aes(x = date, y = adj_close)) +
		geom_line(alpha = .5, color = "navy", lwd = 1) +
		geom_point(color = "navy") +
		geom_vline(xintercept = c(event_begin, event_end),
			lty = 2, color = "darkred", lwd = 1) +
		xlab("") + ylab("Adj. Daily Close") +
		ggtitle(title) +
		theme_bw() + dc_opts
	return(f)
}

##############################################
# Royal Dutch Shell:
f1 <- TS_Plot("RDSB.L", "Royal Dutch Shell Co.")

##############################################
# Rio Tinto:
f2 <- TS_Plot("RIO.L", "Rio Tinto PLC")

##############################################
# Atlas Pipeline Partners:
f3 <- TS_Plot("APL", "Atlas Pipeline Partners")

# Combining into a single figure:
grid.arrange(f1, f2, f3, nrow = 1)

