##############################################
## Table 3: Regression Results for Rehearing (March 5, 2012)
##############################################

rm(list = ls())
setwd(wk_dir)

# Loading data:
load("Data/March5.Rdata")

# Loading Plot Options:
source("Code/Helper_Scripts/Plot_Options.R")

##############################################
# Reference level for factor:
rep_5mar$foreign <- with(rep_5mar, relevel(factor(foreign), ref = "US"))

# Model 1:
m1 <- lm(car ~ min_physint, data = rep_5mar)
se1 <- sqrt(diag(vcovHC(m1)))

# Model 2:
m2 <- lm(car ~ min_physint + foreign + min_physint:foreign,
    data = rep_5mar)
se2 <- sqrt(diag(vcovHC(m2)))

# Model 3:
m3 <- lm(car ~ min_physint + foreign + min_physint:foreign + nace_cat, data = rep_5mar,
    subset = nace_cat %nin% c("Uranium", "Support Mining", "Fertilizer", "Building Stone", "Gravel and Sand", "Salt"))
se3 <- sqrt(diag(vcovHC(m3)))

##############################################
# Outputting LaTeX table:

stargazer(m1, m2, m3,
    se = list(se1, se2, se3[!grepl("nace", names(se3))]),
    omit = "nace",
    dep.var.labels = "CAR",
    covariate.labels = c("Rights Index", "$\\mathbb{1}$(Foreign)", "Rights Index$\\times \\mathbb{1}$(Foreign)"),
    ci = FALSE,
    omit.stat = c("rsq", "ser", "f"),
    font.size = "footnotesize",
    label = "tab:dv_car_5mar",
    title = "Regression Results for Rehearing (March 5, 2012)",
    add.lines = list(c("Sub-Sector FE", "", "", "\\checkmark")),
    notes = "Robust Std. Errors in parentheses.",
    notes.append = TRUE)
