##############################################
## Table 6: Ruling (4/17/2013)
##############################################

rm(list = ls())
setwd(wk_dir)

# Loading data:
load("Data/April17.Rdata")

# Loading Plot Options:
source("Code/Helper_Scripts/Plot_Options.R")

##############################################
# Reference level for factor:
rep_17apr$foreign <- with(rep_17apr, relevel(factor(foreign), ref = "US"))

m1 <- lm(car ~ avg_physint, data = rep_17apr)
se1 <- sqrt(diag(vcovHC(m1)))

m2 <- lm(car ~ avg_physint + foreign + avg_physint:foreign,
    data = rep_17apr)
se2 <- sqrt(diag(vcovHC(m2)))

m3 <- lm(car ~ avg_physint + foreign + avg_physint:foreign + nace_cat,
    data = rep_17apr,
    subset = nace_cat %nin% c("Uranium", "Support Mining", "Fertilizer", "Building Stone", "Gravel and Sand", "Salt"))
se3 <- sqrt(diag(vcovHC(m3)))

stargazer(m1, m2, m3,
    se = list(se1, se2, se3[!grepl("nace", names(se3))]),
    omit = "nace",
    dep.var.labels = "CAR",
    covariate.labels = c("Avg. Rights Index", "$\\mathbb{1}$(Foreign)", "Avg. Rights Index$\\times \\mathbb{1}$(Foreign)"),
    ci = FALSE,
    omit.stat = c("rsq", "ser", "f"),
    font.size = "footnotesize",
    label = "tab:dv_car",
    title = "Regression Results for Ruling (April 17, 2013) Using Average of Rights Index across Subsidiaries",
    add.lines = list(c("Sub-Sector FE", "", "", "\\checkmark")),
    notes = "Robust Std. Errors in parentheses.",
    notes.append = TRUE)

