# Function For Estimating Abnormal Returns

Abnormal_Return <- function(stock,
	begin = begin_est_window, end = end_est_window,
	begin_event = begin_event_window, end_event = end_event_window) {

	# Stock DF:
	df <- price_df %>% tbl_df() %>%
		select(ticker_sym, date, daily_return, lse) %>%
		filter(ticker_sym == stock, date >= begin, date <= end)

	# The market index depends on stock exchange:
	if(all(df$lse == 1)) {
		# For estimation:
		index_df <- ftse_df %>%
			filter(date >= begin, date <= end) %>%
			select(date, daily_return)

		# For prediction:
		pred_df <- ftse_df %>%
			filter(date >= begin_event, date <= end_event) %>%
			select(daily_return, date)

	} else if(all(df$lse == 0)) {
		# For estimation:
		index_df <- sandp_df %>%
			filter(date >= begin, date <= end) %>%
			select(date, daily_return)

		# For prediction:
		pred_df <- sandp_df %>%
			filter(date >= begin_event, date <= end_event) %>%
			select(daily_return, date)
	}

	# Some tickers don't have price data:
	if(nrow(df) == 0 | all(df$daily_return == 0)) {
		return(rep(NA, nrow(pred_df)))
	} else {
		# Combining stock and index into df:
		fn_df <- merge(select(df, date, daily_return), index_df,
			by = "date")
		names(fn_df)[names(fn_df) == "daily_return.x"] <- "y"
		names(fn_df)[names(fn_df) == "daily_return.y"] <- "x"

		# Regressing stock price on index during estimation window:
		m <- lm(y ~ x, data = fn_df)

		# Predicting stock price in event window:
		pred_df$pred_return <- predict(m,
			data.frame(x = pred_df$daily_return))
		pred_df <- pred_df %>% tbl_df() %>% select(date, pred_return)

		# Actual stock price in event window`
		act_df <- price_df %>%
			select(daily_return, date) %>%
			filter(ticker_sym == stock, date >= begin_event, date <= end_event)

		car_df <- merge(pred_df, act_df, by = "date", all = TRUE)

		ab_return <- with(car_df, daily_return - pred_return)
		return(ab_return)
	}
}
