##############################################
## Script to Load and Clean Adj Returns Data:
##############################################

setwd(wk_dir)

# Loading code to create leads and lags:
source("Code/Helper_Scripts/leadlag.R")

library(reshape)

##############################################
# Loading data:
setwd("Data")
price_df <- read.csv("AdjClose_Mar2011_May2013.csv")
price_df <- filter(price_df, ticker_sym != "nan")

# Reshaping Data into long form:
price_df <- melt(price_df, id = "ticker_sym")
names(price_df)[2:length(price_df)] <- c("date", "adj_close")
detach(package:reshape)

# Cleaning Dates:
price_df$date <- with(price_df, gsub("X", "", as.character(date)))
price_df$date <- ymd(price_df$date)

# Calculating Daily Return
price_df <- price_df %>%
	arrange(ticker_sym, date) %>%
	filter(!is.na(adj_close)) %>%
	group_by(ticker_sym) %>%
	mutate(adj_close_lag = lag(adj_close),
		daily_return = (adj_close - adj_close_lag) / adj_close_lag) %>%
	filter(!is.na(daily_return)) %>%
	mutate(lse = as.numeric(grepl("\\.L", ticker_sym)))



